Source-Changes-HG archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
[src/trunk]: src/sys/arch Rename L_ADDR to L_PCB and amend some comments acco...
details: https://anonhg.NetBSD.org/src/rev/cd2bd09a75db
branches: trunk
changeset: 749818:cd2bd09a75db
user: rmind <rmind%NetBSD.org@localhost>
date: Thu Dec 10 05:10:00 2009 +0000
description:
Rename L_ADDR to L_PCB and amend some comments accordingly.
diffstat:
sys/arch/acorn26/acorn26/genassym.cf | 5 +-
sys/arch/acorn26/acorn26/locore.S | 8 +-
sys/arch/alpha/alpha/genassym.cf | 5 +-
sys/arch/alpha/alpha/locore.s | 76 +++++++++++++++++-----------------
sys/arch/amiga/amiga/genassym.cf | 4 +-
sys/arch/arm/arm32/cpuswitch.S | 14 +++---
sys/arch/arm/arm32/genassym.cf | 5 +-
sys/arch/arm/include/cpu.h | 2 +-
sys/arch/atari/atari/genassym.cf | 4 +-
sys/arch/cesfic/cesfic/genassym.cf | 4 +-
sys/arch/hp300/hp300/genassym.cf | 5 +-
sys/arch/hp700/hp700/genassym.cf | 5 +-
sys/arch/hp700/hp700/locore.S | 10 ++--
sys/arch/hppa/hppa/copy.S | 10 ++--
sys/arch/hppa/hppa/trap.S | 4 +-
sys/arch/ia64/ia64/genassym.cf | 3 +-
sys/arch/luna68k/luna68k/genassym.cf | 4 +-
sys/arch/m68k/m68k/switch_subr.s | 8 +-
sys/arch/mac68k/mac68k/genassym.cf | 4 +-
sys/arch/mips/mips/copy.S | 42 +++++++++---------
sys/arch/mips/mips/fp.S | 60 +++++++++++++-------------
sys/arch/mips/mips/genassym.cf | 5 +-
sys/arch/mips/mips/locore.S | 15 +++---
sys/arch/mips/mips/locore_mips1.S | 14 +++---
sys/arch/mips/mips/locore_mips3.S | 4 +-
sys/arch/mips/mips/mipsX_subr.S | 24 +++++-----
sys/arch/mvme68k/mvme68k/genassym.cf | 4 +-
sys/arch/news68k/news68k/genassym.cf | 4 +-
sys/arch/next68k/next68k/genassym.cf | 4 +-
sys/arch/powerpc/ibm4xx/genassym.cf | 4 +-
sys/arch/powerpc/include/asm.h | 6 +-
sys/arch/powerpc/oea/genassym.cf | 4 +-
sys/arch/powerpc/powerpc/locore_subr.S | 6 +-
sys/arch/sh3/sh3/genassym.cf | 3 +-
sys/arch/sparc/sparc/genassym.cf | 4 +-
sys/arch/sparc/sparc/locore.s | 4 +-
sys/arch/sparc64/sparc64/genassym.cf | 8 +--
sys/arch/sparc64/sparc64/locore.s | 4 +-
sys/arch/sun2/sun2/genassym.cf | 4 +-
sys/arch/sun2/sun2/locore.s | 4 +-
sys/arch/sun3/sun3/genassym.cf | 4 +-
sys/arch/sun3/sun3/locore.s | 4 +-
sys/arch/sun3/sun3x/genassym.cf | 4 +-
sys/arch/sun3/sun3x/locore.s | 4 +-
sys/arch/vax/vax/genassym.cf | 4 +-
sys/arch/vax/vax/subr.S | 16 +++---
sys/arch/x68k/x68k/genassym.cf | 4 +-
47 files changed, 218 insertions(+), 229 deletions(-)
diffs (truncated from 1947 to 300 lines):
diff -r 591886e7802c -r cd2bd09a75db sys/arch/acorn26/acorn26/genassym.cf
--- a/sys/arch/acorn26/acorn26/genassym.cf Thu Dec 10 05:02:48 2009 +0000
+++ b/sys/arch/acorn26/acorn26/genassym.cf Thu Dec 10 05:10:00 2009 +0000
@@ -1,4 +1,4 @@
-# $NetBSD: genassym.cf,v 1.11 2009/11/27 03:23:03 rmind Exp $
+# $NetBSD: genassym.cf,v 1.12 2009/12/10 05:10:00 rmind Exp $
#
# Copyright (c) 1999 Ben Harris
# All rights reserved.
@@ -30,7 +30,6 @@
include <sys/param.h>
include <sys/proc.h>
-include <sys/user.h>
include <sys/mbuf.h>
include <netinet/in.h>
include <netinet/in_systm.h>
@@ -48,7 +47,7 @@
define PCB_SF offsetof(struct pcb, pcb_sf)
define PCB_ONFAULT offsetof(struct pcb, pcb_onfault)
-define L_ADDR offsetof(struct lwp, l_addr)
+define L_PCB offsetof(struct lwp, l_addr)
define TF_SPSR offsetof(struct trapframe, tf_spsr)
define TF_R0 offsetof(struct trapframe, tf_r0)
diff -r 591886e7802c -r cd2bd09a75db sys/arch/acorn26/acorn26/locore.S
--- a/sys/arch/acorn26/acorn26/locore.S Thu Dec 10 05:02:48 2009 +0000
+++ b/sys/arch/acorn26/acorn26/locore.S Thu Dec 10 05:10:00 2009 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: locore.S,v 1.21 2009/11/27 03:23:03 rmind Exp $ */
+/* $NetBSD: locore.S,v 1.22 2009/12/10 05:10:00 rmind Exp $ */
/*
* Copyright (c) 1998, 1999, 2000 Ben Harris
* Copyright (C) 1994-1997 Mark Brinicombe
@@ -391,7 +391,7 @@
teq r0, #0x00000000
beq Lswitch_exited
- ldr r3, [r0, #(L_ADDR)]
+ ldr r3, [r0, #(L_PCB)]
add r3, r3, #PCB_SF /* r3 = oldpcb->pcb_sf */
mov r2, sp /* Temporary stack pointer */
@@ -400,7 +400,7 @@
Lswitch_exited:
- ldr r2, [r1, #(L_ADDR)]
+ ldr r2, [r1, #(L_PCB)]
ldr r3, [r2, #(PCB_SF)] /* r3 = newpcb->pcb_sf */
ldmfd r3, {r4-r11, r13-r14} /* Restore from old switchframe */
@@ -452,4 +452,4 @@
ldmfd r13!, {pc}
#endif
-RCSID("$NetBSD: locore.S,v 1.21 2009/11/27 03:23:03 rmind Exp $")
+RCSID("$NetBSD: locore.S,v 1.22 2009/12/10 05:10:00 rmind Exp $")
diff -r 591886e7802c -r cd2bd09a75db sys/arch/alpha/alpha/genassym.cf
--- a/sys/arch/alpha/alpha/genassym.cf Thu Dec 10 05:02:48 2009 +0000
+++ b/sys/arch/alpha/alpha/genassym.cf Thu Dec 10 05:10:00 2009 +0000
@@ -1,4 +1,4 @@
-# $NetBSD: genassym.cf,v 1.17 2009/11/27 03:23:04 rmind Exp $
+# $NetBSD: genassym.cf,v 1.18 2009/12/10 05:10:00 rmind Exp $
#
# Copyright (c) 1982, 1990, 1993
@@ -72,7 +72,6 @@
include <sys/sched.h>
include <sys/mbuf.h>
include <sys/msgbuf.h>
-include <sys/user.h>
include <sys/syscall.h>
include <machine/cpu.h>
@@ -141,7 +140,7 @@
define ALPHA_PTE_KW ALPHA_PTE_KW
# Important offsets into the lwp and proc structs & associated constants
-define L_ADDR offsetof(struct lwp, l_addr)
+define L_PCB offsetof(struct lwp, l_addr)
define L_STAT offsetof(struct lwp, l_stat)
define L_CPU offsetof(struct lwp, l_cpu)
define L_PROC offsetof(struct lwp, l_proc)
diff -r 591886e7802c -r cd2bd09a75db sys/arch/alpha/alpha/locore.s
--- a/sys/arch/alpha/alpha/locore.s Thu Dec 10 05:02:48 2009 +0000
+++ b/sys/arch/alpha/alpha/locore.s Thu Dec 10 05:10:00 2009 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: locore.s,v 1.117 2009/11/27 03:23:04 rmind Exp $ */
+/* $NetBSD: locore.s,v 1.118 2009/12/10 05:10:00 rmind Exp $ */
/*-
* Copyright (c) 1999, 2000 The NetBSD Foundation, Inc.
@@ -67,7 +67,7 @@
#include <machine/asm.h>
-__KERNEL_RCSID(0, "$NetBSD: locore.s,v 1.117 2009/11/27 03:23:04 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: locore.s,v 1.118 2009/12/10 05:10:00 rmind Exp $");
#include "assym.h"
@@ -670,7 +670,7 @@
/*
* do an inline savectx(), to save old context
*/
- ldq a2, L_ADDR(a0)
+ ldq a2, L_PCB(a0)
/* NOTE: ksp is stored by the swpctx */
stq s0, PCB_CONTEXT+(0 * 8)(a2) /* store s0 - s6 */
stq s1, PCB_CONTEXT+(1 * 8)(a2)
@@ -692,9 +692,9 @@
stq s2, CPU_INFO_CURLWP(v0) /* curlwp = l */
/*
* Now running on the new u struct.
*/
- ldq s0, L_ADDR(s2)
+ ldq s0, L_PCB(s2)
/*
* Check for restartable atomic sequences (RAS).
@@ -812,13 +812,13 @@
lda v0, copyerr /* set up fault handler. */
.set noat
ldq at_reg, 0(s0)
- ldq at_reg, L_ADDR(at_reg)
+ ldq at_reg, L_PCB(at_reg)
stq v0, PCB_ONFAULT(at_reg)
.set at
CALL(copystr) /* do the copy. */
.set noat
ldq at_reg, 0(s0) /* kill the fault handler. */
- ldq at_reg, L_ADDR(at_reg)
+ ldq at_reg, L_PCB(at_reg)
stq zero, PCB_ONFAULT(at_reg)
.set at
ldq ra, (16-8)(sp) /* restore ra. */
@@ -841,13 +841,13 @@
lda v0, copyerr /* set up fault handler. */
.set noat
ldq at_reg, 0(s0)
- ldq at_reg, L_ADDR(at_reg)
+ ldq at_reg, L_PCB(at_reg)
stq v0, PCB_ONFAULT(at_reg)
.set at
CALL(copystr) /* do the copy. */
.set noat
ldq at_reg, 0(s0) /* kill the fault handler. */
- ldq at_reg, L_ADDR(at_reg)
+ ldq at_reg, L_PCB(at_reg)
stq zero, PCB_ONFAULT(at_reg)
.set at
ldq ra, (16-8)(sp) /* restore ra. */
@@ -881,13 +881,13 @@
ldq s1, 0(v0) /* s1 = curlwp */
lda v0, kcopyerr /* set up fault handler. */
.set noat
- ldq at_reg, L_ADDR(s1)
+ ldq at_reg, L_PCB(s1)
ldq s0, PCB_ONFAULT(at_reg) /* save old handler. */
stq v0, PCB_ONFAULT(at_reg)
.set at
CALL(memcpy) /* do the copy. */
.set noat
- ldq at_reg, L_ADDR(s1) /* restore the old handler. */
+ ldq at_reg, L_PCB(s1) /* restore the old handler. */
stq s0, PCB_ONFAULT(at_reg)
.set at
ldq ra, (32-8)(sp) /* restore ra. */
@@ -901,7 +901,7 @@
LEAF(kcopyerr, 0)
LDGP(pv)
.set noat
- ldq at_reg, L_ADDR(s1) /* restore the old handler. */
+ ldq at_reg, L_PCB(s1) /* restore the old handler. */
stq s0, PCB_ONFAULT(at_reg)
.set at
ldq ra, (32-8)(sp) /* restore ra. */
@@ -928,12 +928,12 @@
ldq s0, 0(v0) /* s0 = curlwp */
lda v0, copyerr /* set up fault handler. */
.set noat
- ldq at_reg, L_ADDR(s0)
+ ldq at_reg, L_PCB(s0)
stq v0, PCB_ONFAULT(at_reg)
.set at
CALL(memcpy) /* do the copy. */
.set noat
- ldq at_reg, L_ADDR(s0) /* kill the fault handler. */
+ ldq at_reg, L_PCB(s0) /* kill the fault handler. */
stq zero, PCB_ONFAULT(at_reg)
.set at
ldq ra, (16-8)(sp) /* restore ra. */
@@ -960,12 +960,12 @@
ldq s0, 0(v0) /* s0 = curlwp */
lda v0, copyerr /* set up fault handler. */
.set noat
- ldq at_reg, L_ADDR(s0)
+ ldq at_reg, L_PCB(s0)
stq v0, PCB_ONFAULT(at_reg)
.set at
CALL(memcpy) /* do the copy. */
.set noat
- ldq at_reg, L_ADDR(s0) /* kill the fault handler. */
+ ldq at_reg, L_PCB(s0) /* kill the fault handler. */
stq zero, PCB_ONFAULT(at_reg)
.set at
ldq ra, (16-8)(sp) /* restore ra. */
@@ -1004,13 +1004,13 @@
ldq t1, 0(v0)
lda t0, fswberr
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq t0, PCB_ONFAULT(at_reg)
.set at
ldq v0, 0(a0)
zap v0, 0xf0, v0
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq zero, PCB_ONFAULT(at_reg)
.set at
RET
@@ -1027,12 +1027,12 @@
ldq t1, 0(v0)
lda t0, fswberr
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq t0, PCB_ONFAULT(at_reg)
.set at
/* XXX FETCH IT */
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq zero, PCB_ONFAULT(at_reg)
.set at
RET
@@ -1049,12 +1049,12 @@
ldq t1, 0(v0)
lda t0, fswberr
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq t0, PCB_ONFAULT(at_reg)
.set at
/* XXX FETCH IT */
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq zero, PCB_ONFAULT(at_reg)
.set at
RET
@@ -1070,12 +1070,12 @@
ldq t1, 0(v0)
lda t0, fswberr
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq t0, PCB_ONFAULT(at_reg)
.set at
stq a1, 0(a0) /* do the store. */
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq zero, PCB_ONFAULT(at_reg)
.set at
mov zero, v0
@@ -1093,12 +1093,12 @@
ldq t1, 0(v0)
lda t0, fswberr
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq t0, PCB_ONFAULT(at_reg)
.set at
/* XXX STORE IT */
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq zero, PCB_ONFAULT(at_reg)
.set at
call_pal PAL_OSF1_imb /* sync instruction stream */
@@ -1116,12 +1116,12 @@
ldq t1, 0(v0)
lda t0, fswberr
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq t0, PCB_ONFAULT(at_reg)
.set at
/* XXX STORE IT */
.set noat
- ldq at_reg, L_ADDR(t1)
+ ldq at_reg, L_PCB(t1)
stq zero, PCB_ONFAULT(at_reg)
Home |
Main Index |
@@ -692,9 +692,9 @@
stq s2, CPU_INFO_CURLWP(v0) /* curlwp = l */
/*
- * Now running on the new u struct.
+ * Now running on the new PCB.
*/
Thread Index |
Old Index